# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.projects_api import ProjectsApi  # noqa: E501
from asana.rest import ApiException


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_custom_field_setting_for_project(self):
        """Test case for add_custom_field_setting_for_project

        Add a custom field to a project  # noqa: E501
        """
        pass

    def test_add_followers_for_project(self):
        """Test case for add_followers_for_project

        Add followers to a project  # noqa: E501
        """
        pass

    def test_add_members_for_project(self):
        """Test case for add_members_for_project

        Add users to a project  # noqa: E501
        """
        pass

    def test_create_project(self):
        """Test case for create_project

        Create a project  # noqa: E501
        """
        pass

    def test_create_project_for_team(self):
        """Test case for create_project_for_team

        Create a project in a team  # noqa: E501
        """
        pass

    def test_create_project_for_workspace(self):
        """Test case for create_project_for_workspace

        Create a project in a workspace  # noqa: E501
        """
        pass

    def test_delete_project(self):
        """Test case for delete_project

        Delete a project  # noqa: E501
        """
        pass

    def test_duplicate_project(self):
        """Test case for duplicate_project

        Duplicate a project  # noqa: E501
        """
        pass

    def test_get_project(self):
        """Test case for get_project

        Get a project  # noqa: E501
        """
        pass

    def test_get_projects(self):
        """Test case for get_projects

        Get multiple projects  # noqa: E501
        """
        pass

    def test_get_projects_for_task(self):
        """Test case for get_projects_for_task

        Get projects a task is in  # noqa: E501
        """
        pass

    def test_get_projects_for_team(self):
        """Test case for get_projects_for_team

        Get a team's projects  # noqa: E501
        """
        pass

    def test_get_projects_for_workspace(self):
        """Test case for get_projects_for_workspace

        Get all projects in a workspace  # noqa: E501
        """
        pass

    def test_get_task_counts_for_project(self):
        """Test case for get_task_counts_for_project

        Get task count of a project  # noqa: E501
        """
        pass

    def test_project_save_as_template(self):
        """Test case for project_save_as_template

        Create a project template from a project  # noqa: E501
        """
        pass

    def test_remove_custom_field_setting_for_project(self):
        """Test case for remove_custom_field_setting_for_project

        Remove a custom field from a project  # noqa: E501
        """
        pass

    def test_remove_followers_for_project(self):
        """Test case for remove_followers_for_project

        Remove followers from a project  # noqa: E501
        """
        pass

    def test_remove_members_for_project(self):
        """Test case for remove_members_for_project

        Remove users from a project  # noqa: E501
        """
        pass

    def test_update_project(self):
        """Test case for update_project

        Update a project  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
